==> haskell-byte-order-0.1.3.1-103-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-byte-order.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 byte-order
version:              0.1.3.1
visibility:           public
id:                   byte-order-0.1.3.1-7UGP2bWihRQ1XaWeRkwBS9
key:                  byte-order-0.1.3.1-7UGP2bWihRQ1XaWeRkwBS9
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           amartin@layer3com.com
author:               Andrew Martin
homepage:             https://github.com/byteverse/byte-order
synopsis:             Portable big-endian and little-endian conversions
description:
    This library provides an interface to portably work with byte
    arrays whose contents are known to be of a fixed endianness.
    There are two ways to use this module. See the `System.ByteOrder`
    module for more documentation.

category:             Data
abi:                  f33764c75adf8fe87863c85d69affc46
exposed:              True
exposed-modules:
    Data.Primitive.ByteArray.BigEndian
    Data.Primitive.ByteArray.LittleEndian Data.Primitive.Ptr.BigEndian
    System.ByteOrder System.ByteOrder.Class

import-dirs:          /usr/lib/ghc-9.4.8/site-local/byte-order-0.1.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/byte-order-0.1.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/byte-order-0.1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-byte-order
hs-libraries:         HSbyte-order-0.1.3.1-7UGP2bWihRQ1XaWeRkwBS9
depends:
    base-4.17.2.1 primitive-0.9.1.0-KawCla5BA6F2MLtBZRS1Dh
    primitive-unaligned-0.1.1.2-HgIS9XWJMErCBIoXqyA7f0
    wide-word-0.1.7.1-FvMO6nqtiTYLPERD2BDP5t

haddock-interfaces:   /usr/share/doc/haskell-byte-order/html/byte-order.haddock
haddock-html:         /usr/share/doc/haskell-byte-order/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-byte-order-0.1.3.1-104-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-byte-order.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 byte-order
version:              0.1.3.1
visibility:           public
id:                   byte-order-0.1.3.1-EtWmaXhx1SwLre3wKUPpAz
key:                  byte-order-0.1.3.1-EtWmaXhx1SwLre3wKUPpAz
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           amartin@layer3com.com
author:               Andrew Martin
homepage:             https://github.com/byteverse/byte-order
synopsis:             Portable big-endian and little-endian conversions
description:
    This library provides an interface to portably work with byte
    arrays whose contents are known to be of a fixed endianness.
    There are two ways to use this module. See the `System.ByteOrder`
    module for more documentation.

category:             Data
abi:                  e43e992494950c9cfd51dce73002ba3d
exposed:              True
exposed-modules:
    Data.Primitive.ByteArray.BigEndian
    Data.Primitive.ByteArray.LittleEndian Data.Primitive.Ptr.BigEndian
    System.ByteOrder System.ByteOrder.Class

import-dirs:          /usr/lib/ghc-9.4.8/site-local/byte-order-0.1.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/byte-order-0.1.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/byte-order-0.1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-byte-order
hs-libraries:         HSbyte-order-0.1.3.1-EtWmaXhx1SwLre3wKUPpAz
depends:
    base-4.17.2.1 primitive-0.9.1.0-CJdTcKbxsQE2upc4cw9myr
    primitive-unaligned-0.1.1.2-Fo9e14cUk1CFnq8yuG9t0W
    wide-word-0.1.7.1-Are5HBoYUbW6HCBHE5YQsr

haddock-interfaces:   /usr/share/doc/haskell-byte-order/html/byte-order.haddock
haddock-html:         /usr/share/doc/haskell-byte-order/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
